@@ -1,7 +1,8 @@
-__all__ = ["color", "parser", "load", "scroll"]
+__all__ = ["color", "parser", "load", "scroll, clear"]
 
 import bd103.color
-from bd103.color import paint
+from bd103.color import print, paint
 from bd103.parser import grid, space
 from bd103.load import load, loadbar
-from bd103.scroll import scroll
\ No newline at end of file
+from bd103.scroll import scroll
+from bd103.clear import clear
\ No newline at end of file
