@@ -2,7 +2,7 @@
 Color Module for the BD103 Package
 '''
 
-def print(text, color):
+def cprint(text, color):
     if color == "reset":
         print("\u001b[0m" + text)
     elif color == "red":
@@ -24,20 +24,20 @@ def print(text, color):
 
 def paint(color):
     if color == "reset":
-        print("\u001b[0m")
+        cprint("", "reset")
     elif color == "red":
-        print("\u001b[31m")
+        cprint("", "red")
     elif color == "yellow":
-        print("\u001b[33m")
+        cprint("", "yellow")
     elif color == "green":
-        print("\u001b[32m")
+        cprint("", "green")
     elif color == "cyan":
-        print("\u001b[36m")
+        cprint("", "cyan")
     elif color == "blue":
-        print("\u001b[34m")
+        cprint("", "blue")
     elif color == "magenta":
-        print("\u001b[35m")
+        cprint("", "magenta")
     elif color == "black":
-        print("\u001b[30m")
+        cprint("", "black")
     elif color == "white":
-        print("\u001b[37m")
\ No newline at end of file
+        cprint("", "white")
\ No newline at end of file
