@@ -1,6 +1,10 @@
+'''
+Scrolling Text Module for the BD103 Package
+'''
+
 import time
 
-def scroll(text):
+def scroll(text, delay=0.03):
 	i = 0
 	length = len(text)
 	output = ""
@@ -8,5 +12,5 @@ def scroll(text):
 		output = output+text[i]
 		print(output, end="\r")
 		i = i+1
-		time.sleep(0.03)
+		time.sleep(delay)
 	print()
\ No newline at end of file
